@@ -15,10 +15,8 @@
 #include <QDBusPendingCallWatcher>
 #include <QDBusPendingReply>
 
-Request::Request(const QDBusObjectPath &handle, QObject *parent, const QString &portalName, const QVariant &data)
+Request::Request(const QDBusObjectPath &handle, QObject *parent)
     : QDBusVirtualObject(parent)
-    , m_data(data)
-    , m_portalName(portalName)
 {
     auto sessionBus = QDBusConnection::sessionBus();
     if (sessionBus.registerVirtualObject(handle.path(), this, QDBusConnection::VirtualObjectRegisterOption::SubPath)) {
@@ -35,8 +33,6 @@ Request::Request(const QDBusObjectPath &handle, QObject *parent, const QString &
 
 bool Request::handleMessage(const QDBusMessage &message, const QDBusConnection &connection)
 {
-    Q_UNUSED(connection);
-
     /* Check to make sure we're getting properties on our interface */
     if (message.type() != QDBusMessage::MessageType::MethodCallMessage) {
         return false;
@@ -49,8 +45,7 @@ bool Request::handleMessage(const QDBusMessage &message, const QDBusConnection &
     if (message.interface() == QLatin1String("org.freedesktop.impl.portal.Request")) {
         if (message.member() == QLatin1String("Close")) {
             Q_EMIT closeRequested();
-            QDBusMessage reply = message.createReply();
-            return connection.send(reply);
+            connection.send(message.createReply());
         }
     }
 
